@@ -1,33 +1,28 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /* libwps
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2003 William Lachance (william.lachance@sympatico.ca)
  * Copyright (C) 2003-2004 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2004-2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  * Copyright (C) 2006, 2007 Andrew Ziem (andrewziem users sourceforge net)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * For minor contributions see the git repository.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwps.sourceforge.net
  */
 
-/*
- * This file is in sync with CVS
- * /libwpd2/src/lib/WPDocument.cpp 1.34
- */
-
-#include "WPSDocument.h"
+#include <libwps/libwps.h>
 #include "WPS4.h"
 #include "WPS8.h"
 #include "WPSHeader.h"
@@ -72,17 +67,17 @@ WPSConfidence WPSDocument::isFileFormatSupported(WPXInputStream *ip)
 
 		switch (header->getMajorVersion())
 		{
-
 		case 8:
 		case 7:
 		case 4:
 			confidence = WPS_CONFIDENCE_EXCELLENT;
 			break;
-
 		case 5:
 		case 2:
 			confidence = WPS_CONFIDENCE_GOOD;
 			break;
+		default:
+			break;
 		}
 
 		return confidence;
@@ -127,7 +122,6 @@ WPSResult WPSDocument::parse(WPXInputStream *ip, WPXDocumentInterface *documentI
 
 		switch (header->getMajorVersion())
 		{
-
 		case 8:
 		case 7:
 		case 6:
@@ -148,6 +142,8 @@ WPSResult WPSDocument::parse(WPXInputStream *ip, WPXDocumentInterface *documentI
 			parser->parse(documentInterface);
 			break;
 		}
+		default:
+			break;
 		}
 	}
 	catch (libwps::FileException)
