@@ -1,32 +1,28 @@
 /* -*- Mode: C++; c-default-style: "k&r"; indent-tabs-mode: nil; tab-width: 2; c-basic-offset: 2 -*- */
 /* libwps
+ * Version: MPL 2.0 / LGPLv2.1+
+ *
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * Major Contributor(s):
  * Copyright (C) 2009, 2011 Alonso Laurent (alonso@loria.fr)
  * Copyright (C) 2006, 2007 Andrew Ziem
  * Copyright (C) 2004-2006 Fridrich Strba (fridrich.strba@bluewin.ch)
  * Copyright (C) 2004 Marc Maurer (uwog@uwog.net)
  * Copyright (C) 2003-2005 William Lachance (william.lachance@sympatico.ca)
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * For minor contributions see the git repository.
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+ * Alternatively, the contents of this file may be used under the terms
+ * of the GNU Lesser General Public License Version 2.1 or later
+ * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
+ * applicable instead of those above.
  *
  * For further information visit http://libwps.sourceforge.net
  */
 
-/* "This product is not manufactured, approved, or supported by
- * Corel Corporation or Corel Corporation Limited."
- */
-
 #include <string>
 #include <sstream>
 
@@ -42,7 +38,7 @@ namespace libwps_tools_win
 
 Font::Type Font::getWin3Type(std::string &fName)
 {
-	int len = fName.length();
+	size_t len = fName.length();
 	if (len && fName[len-1] != ')')
 	{
 		if (fName == "Baltica" || fName == "Pragmatica")
@@ -308,7 +304,7 @@ unsigned long Font::unicodeFromCP1255(unsigned char c)
 		0x05E8, 0x05E9, 0x05EA, UNDEF /* 0xfb */, UNDEF /* 0xfc */, 0x200E, 0x200F, UNDEF /* 0xff */,
 	};
 	if (c < 0x80) return c;
-	return cp1255[c - 0x80];
+	return (unsigned long)cp1255[c - 0x80];
 }
 
 /**
@@ -337,7 +333,7 @@ unsigned long Font::unicodeFromCP1256(unsigned char c)
 		0x0651, 0x00F9, 0x0652, 0x00FB, 0x00FC, 0x200E, 0x200F, 0x06D2,
 	};
 	if (c < 0x80) return c;
-	return cp1256[c - 0x80];
+	return (unsigned long) cp1256[c - 0x80];
 }
 
 
@@ -492,7 +488,8 @@ std::string Language::name(long id)
 		return "english(Philippines)";
 	case 0x480A:
 		return "spanish(Honduras)";
-
+	default:
+		break;
 	}
 
 	std::stringstream f;
